<?php

namespace ByDedi\MediaBundle\Entity;

use ByDedi\AdminBundle\Annotation\Uploadable;
use ByDedi\AdminBundle\Entity\Traits\Translatable;
use Doctrine\ORM\Mapping as ORM;
use Knp\DoctrineBehaviors\Model as ORMBehaviors;
use Symfony\Component\HttpFoundation\File\File;
use Symfony\Component\HttpFoundation\File\UploadedFile;

/**
 * Image
 *
 * @ORM\Table(name="image")
 * @ORM\Entity(repositoryClass="ByDedi\MediaBundle\Repository\ImageRepository")
 * @ORM\HasLifecycleCallbacks()
 */
class Image
{
    use ORMBehaviors\Translatable\Translatable;
    use ORMBehaviors\Timestampable\Timestampable;
    use Translatable;

    /**
     * @var int
     *
     * @ORM\Column(name="id", type="integer")
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="AUTO")
     */
    private $id;

    /**
     * @var string
     *
     * @ORM\Column(name="path", type="string", length=255)
     */
    private $path;

    /**
     * @var File
     *
     * @Uploadable(filename="path", path="uploads/images")
     */
    private $pathFile;

    /**
     * @var string
     *
     * @ORM\Column(name="width", type="integer")
     */
    private $width;

    /**
     * @var string
     *
     * @ORM\Column(name="height", type="integer")
     */
    private $height;

    /**
     * @var string
     *
     * @ORM\Column(name="size", type="integer")
     */
    private $size;

    /**
     * @var string
     */
    protected $uploadDir = 'images/';


    /**
     * Get id
     *
     * @return int
     */
    public function getId()
    {
        return $this->id;
    }

    /**
     * Set path
     *
     * @param string $path
     *
     * @return Image
     */
    public function setPath($path)
    {
        $this->path = $path;

        return $this;
    }

    /**
     * Get path
     *
     * @return string
     */
    public function getPath()
    {
        return $this->path;
    }

    /**
     * @return string
     */
    public function getWidth()
    {
        return $this->width;
    }

    /**
     * @param string $width
     */
    public function setWidth($width)
    {
        $this->width = $width;
    }

    /**
     * @return string
     */
    public function getHeight()
    {
        return $this->height;
    }

    /**
     * @param string $height
     */
    public function setHeight($height)
    {
        $this->height = $height;
    }

    /**
     * @return string
     */
    public function getSize()
    {
        return $this->size;
    }

    /**
     * @param string $size
     */
    public function setSize($size)
    {
        $this->size = $size;
    }



    /**
     * @return string
     */
    public function __toString()
    {
        return (string)$this->getName();
    }

    /**
     * @return null|string
     */
    public function getFullPath()
    {
        $currentPath = $this->getPath();
        return (!empty($currentPath) ? '/'.$currentPath : null);
    }

    /**
     * @return string
     */
    public function getDimensionsString()
    {
        return $this->width.'px / '.$this->height.'px';
    }

    /**
     * @return string
     */
    public function getWeightInMB()
    {
        return round(($this->size/1000000), 2).' MB';
    }

    /**
     * @return File
     */
    public function getPathFile()
    {
        return $this->pathFile;
    }

    /**
     * @param File $pathFile
     */
    public function setPathFile($pathFile)
    {
        $this->pathFile = $pathFile;
    }


    /**
     * @ORM\PrePersist
     * @ORM\PreFlush
     */
    public function setImageMetaData()
    {
        if ($this->getPathFile() instanceof UploadedFile && $this->getPathFile()->getRealPath() !== false) {
            $fileName = $this->getPathFile()->getPathname();
            $size = @getimagesize($fileName);
            $weight = @filesize($fileName);
            if (empty($size)) {
                $size = [0,0];
            }
            if (empty($weight)) {
                $weight = 0;
            }
            $this->setSize($weight);
            $this->setWidth($size[0]);
            $this->setHeight($size[1]);
        }
    }
}
